// This is a simple sketch for switching through different colors and animating a lightsaber
// using the NeoPixel led strip (60 leds per strip)
// i used two of them so a decent powersupply should be added or the brightness turned down!
// code used on a Adafruit Trinket 5V

// Code mostly by Adafruit 
// a few things removed/added by DirAgAlok
// more to come at www.diragalok.at
// Licence: creative common
// 2018

#include <Adafruit_NeoPixel.h>

#define BUTTON_PIN   3    // Digital IO pin connected to the button.  This will be
                          // driven with a pull-up resistor so the switch should
                          // pull the pin to ground momentarily.  On a high -> low
                          // transition the button press logic will execute.

#define PIXEL_PIN    6    // Digital IO pin connected to the NeoPixels.

#define PIXEL_COUNT 60    // correct for your number of pixels per strip

#define FillTime 1        // the higher the slower the strip will fill

#define brightness 150    // adjust the brightness (0-255, the higher the more Amps will be drawn)

// Parameter 1 = number of pixels in strip
// Parameter 2 = pin number (most are valid)
// Parameter 3 = pixel type flags, add together as needed:
//   NEO_RGB     Pixels are wired for RGB bitstream
//   NEO_GRB     Pixels are wired for GRB bitstream, correct for neopixel stick
//   NEO_KHZ400  400 KHz bitstream (e.g. FLORA pixels)
//   NEO_KHZ800  800 KHz bitstream (e.g. High Density LED strip), correct for neopixel stick
Adafruit_NeoPixel strip = Adafruit_NeoPixel(PIXEL_COUNT, PIXEL_PIN, NEO_GRBW + NEO_KHZ800);

bool oldState = HIGH;
int showType = 0;

void setup() {
  // This is for Trinket 5V 16MHz, you can remove these three lines if you are not using a Trinket
  #if defined (__AVR_ATtiny85__)
    if (F_CPU == 16000000) clock_prescale_set(clock_div_1);
  #endif
  pinMode(BUTTON_PIN, INPUT_PULLUP);
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
}

void loop() {
  // Get current button state.
  bool newState = digitalRead(BUTTON_PIN);

  // Check if state changed from high to low (button press).
  if (newState == LOW && oldState == HIGH) {
    // Short delay to debounce button.
    delay(20);
    // Check if button is still low after debounce.
    newState = digitalRead(BUTTON_PIN);
    if (newState == LOW) {
      showType++;
      if (showType > 8)
        showType=0;
      startShow(showType);
    }
  }

  // Set the last button state to the old state.
  oldState = newState;
}

void startShow(int i) {
  switch(i){
    case 0: clearStripe();
            break;
            
    case 1: clearStripe();
            strip.setPixelColor(0, 32, 0, 0);
            strip.show();
            break;

    case 2: colorWipe(strip.Color(brightness, 0, 0), FillTime);  // Red
            strip.show();
            break;
            
    case 3: clearStripe();
            strip.setPixelColor(0, 0, 32, 0);
            strip.show();
            break;
           
    case 4: colorWipe(strip.Color(0, brightness, 0), FillTime);  // Green
            strip.show();
            break;
            
    case 5: clearStripe();
            strip.setPixelColor(0, 0, 0, 32);
            strip.show();
            break;
           
    case 6: colorWipe(strip.Color(0, 0, brightness), FillTime);  // Blue
            strip.show();
            break;
            
    case 7: clearStripe();
            strip.setPixelColor(0, 32, 32, 32);
            strip.show();
            break;
           
    case 8: colorWipe(strip.Color(56, 56, 56), FillTime); // White
            strip.show();
            break;
            
    
  }
}

// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
 
  for(uint16_t i=0; i<strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }
}

void clearStripe()
{
   for (int i = 0; i < PIXEL_COUNT; i++)  strip.setPixelColor(i, 0);
  strip.show();
  }
